@@ -4,5 +4,8 @@ from django.http import HttpResponse
 def flash_context(request):
     flash = None
     if 'flashcookie' in request.COOKIES:
-        flash = simplejson.loads(request.COOKIES['flashcookie'])
+        try:
+            flash = simplejson.loads(request.COOKIES['flashcookie'])
+        except ValueError:
+            pass
     return {'flash': flash}
